@@ -2,7 +2,7 @@
 /* ssdeep
    (C) Copyright 2006 ManTech International Corporation
 
-   $Id: helpers.c 61 2008-02-22 23:18:59Z jessekornblum $
+   $Id: helpers.c 97 2010-03-19 15:10:06Z jessekornblum $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #include "ssdeep.h"
 
-void try(void)
+void try_msg(void)
 {
   fprintf (stderr,"Try `%s -h` for more information.%s", __progname, NEWLINE);
 }
@@ -34,7 +34,7 @@ void sanity_check(state *s, int condition, char *msg)
       if (!(s->mode & mode_silent))
 	{
 	  print_status("%s: %s", __progname, msg);
-	  try();
+	  try_msg();
 	}
       exit (EXIT_FAILURE);
     }
