@@ -1,7 +1,7 @@
 // Fuzzy Hashing by Jesse Kornblum
-// Copyright (C) 2008,2009 ManTech International Corporation
+// Copyright (C) 2010 ManTech International Corporation
 //
-// $Id: main.c 33 2008-02-16 18:37:47Z jessekornblum 
+// $Id: main.c 97 2010-03-19 15:10:06Z jessekornblum $
 //
 // This program is licensed under version 2 of the GNU Public License.
 // See the file COPYING for details. 
@@ -28,11 +28,14 @@ static int initialize_state(state *s)
 static void usage(void)
 {
   print_status ("%s version %s by Jesse Kornblum", __progname, VERSION);
-  print_status ("Copyright (C) 2008 ManTech International Corporation");
+  print_status ("Copyright (C) 2010 ManTech International Corporation");
   print_status ("");
-  print_status ("Usage: %s [-V|h] [-m file] [-vprdsblcx] [-t val] [FILES]", 
+  print_status ("Usage: %s [-m file] [-k file] [-vprdsblcxa] [-t val] [-h|-V] [FILES]", 
 	  __progname);
 
+  print_status ("-m - Match FILES against known hashes in file");
+  print_status ("-k - Match signatures in FILES against signatures in file");
+
   print_status ("-v - Verbose mode. Displays filename as its being processed");
   print_status ("-p - Pretty matching mode. Similar to -d but includes all matches");
   print_status ("-r - Recursive mode");
@@ -42,8 +45,10 @@ static void usage(void)
   print_status ("-l - Uses relative paths for filenames");
   print_status ("-c - Prints output in CSV format");
   print_status ("-x - Compare FILES as signature files");
+  print_status ("-a - Display all matches, regardless of score");
+
   print_status ("-t - Only displays matches above the given threshold");
-  print_status ("-m - Match FILES against known hashes in file");
+
   print_status ("-h - Display this help message");
   print_status ("-V - Display version number and exit");
 }
@@ -52,14 +57,20 @@ static void usage(void)
 static void process_cmd_line(state *s, int argc, char **argv)
 {
   int i, match_files_loaded = FALSE;
-  while ((i=getopt(argc,argv,"vhVpdsblcxt:rm:")) != -1) {
+  while ((i=getopt(argc,argv,"avhVpdsblcxt:rm:k:")) != -1) {
     switch(i) {
 
+    case 'a':
+      s->mode |= mode_display_all;
+      break;
+
     case 'v': 
       if (MODE(mode_verbose))
       {
 	print_error(s,"%s: Already at maximum verbosity", __progname);
-	print_error(s,"%s: Error message display to user correctly", __progname);
+	print_error(s,
+		    "%s: Error message display to user correctly", 
+		    __progname);
       }
       else
 	s->mode |= mode_verbose;
@@ -86,6 +97,8 @@ static void process_cmd_line(state *s, int argc, char **argv)
       s->mode |= mode_csv; break;
 
     case 'x':
+      if (MODE(mode_match) || MODE(mode_sigcompare))
+	fatal_error("Signature matching cannot be combined with other matching modes");
       s->mode |= mode_sigcompare; break;
 
     case 'r':
@@ -99,11 +112,21 @@ static void process_cmd_line(state *s, int argc, char **argv)
       break;
       
     case 'm':
+      if (MODE(mode_compare_unknown) || MODE(mode_sigcompare))
+	fatal_error("Positive matching cannot be combined with other matching modes");
       s->mode |= mode_match;
       if (!match_load(s,optarg))
 	match_files_loaded = TRUE;
       break;
       
+    case 'k':
+      if (MODE(mode_match) || MODE(mode_sigcompare))
+	fatal_error("Signature matching cannot be combined with other matching modes");
+      s->mode |= mode_compare_unknown;
+      if (!match_load(s,optarg))
+	match_files_loaded = TRUE;
+      break;
+
     case 'h':
       usage(); 
       exit (EXIT_SUCCESS);
@@ -113,13 +136,17 @@ static void process_cmd_line(state *s, int argc, char **argv)
       exit (EXIT_SUCCESS);
       
     default:
-      try();
+      try_msg();
       exit (EXIT_FAILURE);
     }
   }
 
+  // We don't include mode_sigcompare in this list as we haven't loaded
+  // the matching files yet. In that mode the matching files are in fact 
+  // the command line arguments.
   sanity_check(s,
-	       ((s->mode & mode_match) && !match_files_loaded),
+	       ((MODE(mode_match) || MODE(mode_compare_unknown))
+		&& !match_files_loaded),
 	       "No matching files loaded");
   
   sanity_check(s,
@@ -247,8 +274,10 @@ int main(int argc, char **argv)
 
   while (count < goal)
   {
-    if (s->mode & mode_sigcompare)
+    if (MODE(mode_sigcompare))
       match_load(s,argv[count]);
+    else if (MODE(mode_compare_unknown))
+      match_compare_unknown(s,argv[count]);
     else
     {
       generate_filename(s,fn,cwd,s->argv[count]);
